summaryrefslogtreecommitdiffstats
path: root/system/core
diff options
context:
space:
mode:
authorPhil Sturgeon <email@philsturgeon.co.uk>2012-04-26 23:09:28 +0200
committerPhil Sturgeon <email@philsturgeon.co.uk>2012-04-26 23:09:28 +0200
commitf3b0074b0ccaadef31737cbd6be21ec7272f7538 (patch)
tree5412753e60ac0704798d8b7099b411f80256fc64 /system/core
parentc7bd2a87f0a23a574f2687b3c2989f7683fd2786 (diff)
parentffe7a0a32c414bfda8a115860a55bf7ceedf6f79 (diff)
Merge pull request #1061 from jamierumbelow/develop
Renamed Active Record class to Query Builder
Diffstat (limited to 'system/core')
-rw-r--r--system/core/Loader.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/system/core/Loader.php b/system/core/Loader.php
index 027ed20e5..5f283dc3a 100644
--- a/system/core/Loader.php
+++ b/system/core/Loader.php
@@ -313,16 +313,16 @@ class CI_Loader {
*
* @param string the DB credentials
* @param bool whether to return the DB object
* @param bool whether to enable active record (this allows us to override the config setting)
* @return object
*/
- public function database($params = '', $return = FALSE, $active_record = NULL)
+ public function database($params = '', $return = FALSE, $query_builder = NULL)
{
// Grab the super object
$CI =& get_instance();
// Do we even need to load the database class?
- if (class_exists('CI_DB') && $return == FALSE && $active_record == NULL && isset($CI->db) && is_object($CI->db))
+ if (class_exists('CI_DB') && $return == FALSE && $query_builder == NULL && isset($CI->db) && is_object($CI->db))
{
return FALSE;
}
@@ -331,7 +331,7 @@ class CI_Loader {
if ($return === TRUE)
{
- return DB($params, $active_record);
+ return DB($params, $query_builder);
}
// Initialize the db variable. Needed to prevent
@@ -339,7 +339,7 @@ class CI_Loader {
$CI->db = '';
// Load the DB class
- $CI->db =& DB($params, $active_record);
+ $CI->db =& DB($params, $query_builder);
}
// --------------------------------------------------------------------
@@ -1254,4 +1254,4 @@ class CI_Loader {
}
/* End of file Loader.php */
-/* Location: ./system/core/Loader.php */ \ No newline at end of file
+/* Location: ./system/core/Loader.php */
@@ -313,16 +313,16 @@ class CI_Loader {
* @param string the DB credentials
* @param bool whether to return the DB object
- * @param bool whether to enable active record (this allows us to override the config setting)
+ * @param bool whether to enable query builder (this allows us to override the config setting)
* @return object
*/